==> release.12.0.73.1.tgz: cgi-cpn/prontus_port_update_by_art.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

# Captura STDERR
use lib_stdlog;
&lib_stdlog::set_stdlog($0, 51200);

use prontus_varglb; &prontus_varglb::init();

use lib_prontus;
use lib_artic;
use lib_helper;

main: {
    &lib_prontus::setUtf8();
    if (scalar @ARGV < 1) {
        print "Parámetros insuficientes. Modo de uso:\n";
        print "perl prontus_port_update_by_art.pl <path_completo_a_html_articulo>, por ejemplo:\n";
        print "perl prontus_port_update_by_art.pl /var/www/misitio.cl/web/miprontus/site/artic/20121029/pags/20121029134513.html\n";
        exit;
    }

    # Ruta hacia el Archivo del Artículo (por ejemplo, /var/www/misitio.cl/web/miprontus/site/artic/20121029/pags/20121029134513.html)
    my $fullpath_art = $ARGV[0];

    my $fechac;
    my $marca_video;
    my $video = '';
    my $ts ='';
    # se usa | como delimitador para facilitar la regexp
    if ($fullpath_art =~ m|/([^\/]+?)/site/artic/\d{8}/pags/(\d{14})\.\w+|) {
        $prontus_varglb::PRONTUS_ID = $1;
        $ts = $2;
    } else {
        print STDERR "Error al leer el TS del artículo [$fullpath_art]\n";
        exit;
    }

    if ($prontus_varglb::PRONTUS_ID eq '' || !&lib_prontus::valida_prontus($prontus_varglb::PRONTUS_ID)) {
        print STDERR "El identificador de prontus es inválido\n";
    }
    my $msg_load = &lib_prontus::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "$msg_load\n";
    }

    &lib_prontus::actualizar_portadas_byartic($ts, 'ALTA_CONTROL');
}

==> release.12.2.28.1.tgz: cgi-cpn/prontus_port_update_by_art.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use Digest::MD5;
use File::Copy;
use HTML::Entities;
use JSON;
use POSIX;
use Time::Local;
use URI::Escape;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_parser;
use lib_ports;
use lib_prontus;
use lib_quota;
use lib_tags;
use lib_tax;
use lib_urlf5;
use lib_utils;
use lib_waitlock;
##/libs##

main: {
    lib_utils::setUtf8();
    if (scalar @ARGV < 1) {
        print "Parámetros insuficientes. Modo de uso:\n";
        print "perl prontus_port_update_by_art.pl <path_completo_a_html_articulo>, por ejemplo:\n";
        print "perl prontus_port_update_by_art.pl /var/www/misitio.cl/web/miprontus/site/artic/20121029/pags/20121029134513.html\n";
        exit;
    }

    # Ruta hacia el Archivo del Artículo (por ejemplo, /var/www/misitio.cl/web/miprontus/site/artic/20121029/pags/20121029134513.html)
    my $fullpath_art = $ARGV[0];

    my $fechac;
    my $marca_video;
    my $video = '';
    my $ts ='';
    # se usa | como delimitador para facilitar la regexp
    if ($fullpath_art =~ m|/([^\/]+?)/site/artic/\d{8}/pags/(\d{14})\.\w+|) {
        $prontus_varglb::PRONTUS_ID = $1;
        $ts = $2;
    } else {
        print STDERR "Error al leer el TS del artículo [$fullpath_art]\n";
        exit;
    }

    if ($prontus_varglb::PRONTUS_ID eq '' || !lib_utils::valida_prontus($prontus_varglb::PRONTUS_ID)) {
        print STDERR "El identificador de prontus es inválido\n";
    }
    my $msg_load = lib_utils::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "$msg_load\n";
    }

    lib_ports::actualizar_portadas_byartic($ts, 'ALTA_CONTROL');
}
